@@ -573,6 +573,222 @@ class test_object_properties(unittest.TestCase):
 
         self.assertRaises(ValueError, incorrect_enrichment_target)
 
+        def test_missing_temperature_He():
+            """checks a ValueError is raised when the temperatue is not set"""
+
+            nmm.Material(
+                material_name="He",
+                pressure_in_Pa=1e6,
+            )
+
+        self.assertRaises(ValueError, test_missing_temperature_He)
+
+        def test_missing_temperature_H2O():
+            """checks a ValueError is raised when the temperatue is not set"""
+
+            nmm.Material(
+                material_name="H2O",
+                pressure_in_Pa=1e6,
+            )
+
+        self.assertRaises(ValueError, test_missing_temperature_H2O)
+
+        def test_missing_temperature_CO2():
+            """checks a ValueError is raised when the temperatue is not set"""
+
+            nmm.Material(
+                material_name="CO2",
+                pressure_in_Pa=1e6,
+            )
+
+        self.assertRaises(ValueError, test_missing_temperature_CO2)
+
+        def test_incorrect_material_name_type():
+            """checks a ValueError is raised when the temperatue is not set"""
+
+            test_material = nmm.Material("H2O",
+                                         temperature_in_C=10,
+                                         pressure_in_Pa=-1e6)
+            test_material.material_name = 1
+
+        self.assertRaises(ValueError, test_incorrect_material_name_type)
+
+        def test_incorrect_density_unit_type():
+            """checks a ValueError is raised when the temperatue is not set"""
+
+            nmm.Material(
+                "eurofer",
+                density=1.,
+                density_unit='grams per cm3')
+
+        self.assertRaises(ValueError, test_incorrect_density_unit_type)
+
+        def test_incorrect_percent_type_type():
+            """checks a ValueError is raised when the temperatue is not set"""
+
+            nmm.Material(
+                "eurofer",
+                density=1.,
+                percent_type='weight percent')
+
+        self.assertRaises(ValueError, test_incorrect_percent_type_type)
+
+        def test_incorrect_enrichment_type_type():
+            """checks a ValueError is raised when the temperatue is not set"""
+
+            nmm.Material(
+                "eurofer",
+                density=1.,
+                enrichment_type='weight percent')
+
+        self.assertRaises(ValueError, test_incorrect_enrichment_type_type)
+
+        def test_incorrect_atoms_per_unit_cell():
+            """checks a ValueError is raised when the temperatue is not set"""
+
+            nmm.Material(
+                "eurofer",
+                atoms_per_unit_cell=-1.)
+
+        self.assertRaises(ValueError, test_incorrect_atoms_per_unit_cell)
+
+        def test_incorrect_volume_of_unit_cell_cm3():
+            """checks a ValueError is raised when the temperatue is not set"""
+
+            nmm.Material(
+                "eurofer",
+                volume_of_unit_cell_cm3=-1.)
+
+        self.assertRaises(ValueError, test_incorrect_volume_of_unit_cell_cm3)
+
+        def test_incorrect_temperature_in_c():
+            """checks a ValueError is raised when the temperatue is not set"""
+
+            nmm.Material(
+                "eurofer",
+                temperature_in_C=-1000.)
+
+        self.assertRaises(ValueError, test_incorrect_temperature_in_c)
+
+        def test_incorrect_temperature_in_k():
+            """checks a ValueError is raised when the temperatue is not set"""
+
+            nmm.Material(
+                "eurofer",
+                temperature_in_K=-1.)
+
+        self.assertRaises(ValueError, test_incorrect_temperature_in_k)
+
+        def test_incorrect_zaid_suffix_type():
+            """checks a ValueError is raised when the temperatue is not set"""
+
+            nmm.Material(
+                "eurofer",
+                zaid_suffix=0.80)
+
+        self.assertRaises(ValueError, test_incorrect_zaid_suffix_type)
+
+        def test_incorrect_packing_fraction():
+            """checks a ValueError is raised when the packing_fraction is the
+            wrong type"""
+
+            nmm.Material(
+                "eurofer",
+                packing_fraction="1"
+            )
+
+        self.assertRaises(ValueError, test_incorrect_packing_fraction)
+
+        def test_too_large_packing_fraction():
+            """checks a ValueError is raised when the packing_fraction is the
+            too large"""
+
+            nmm.Material(
+                "eurofer",
+                packing_fraction=1.1
+            )
+
+        self.assertRaises(ValueError, test_too_large_packing_fraction)
+
+        def test_too_small_packing_fraction():
+            """checks a ValueError is raised when the packing_fraction is the
+            too large"""
+
+            nmm.Material(
+                "eurofer",
+                packing_fraction=-0.1
+            )
+
+        self.assertRaises(ValueError, test_too_small_packing_fraction)
+
+        def test_chemical_equation_wrong_type():
+            """checks a ValueError is raised when the chemical_equation is the
+            not a str"""
+
+            nmm.Material(
+                "eurofer",
+                chemical_equation=-0.1
+            )
+
+        self.assertRaises(ValueError, test_chemical_equation_wrong_type)
+
+        def test_enrichment_too_high():
+            """checks a ValueError is raised when the enrichment is the
+            too large"""
+
+            nmm.Material(
+                "Li4SiO4",
+                enrichment=101,
+                enrichment_target='Li6'
+            )
+
+        self.assertRaises(ValueError, test_enrichment_too_high)
+
+        def test_enrichment_too_low():
+            """checks a ValueError is raised when the enrichment is the
+            too small"""
+
+            nmm.Material(
+                "Li4SiO4",
+                enrichment=-1,
+                enrichment_target='Li6'
+            )
+
+        self.assertRaises(ValueError, test_enrichment_too_low)
+
+        def test_pressure_in_Pa_too_low():
+            """checks a ValueError is raised when the pressure_in_Pa is the
+            too small"""
+
+            nmm.Material(
+                "Li4SiO4",
+                pressure_in_Pa=-1
+            )
+
+        self.assertRaises(ValueError, test_pressure_in_Pa_too_low)
+
+        def test_reference_wrong_type():
+            """checks a ValueError is raised when the reference is the
+            not a string"""
+
+            nmm.Material(
+                "Li4SiO4",
+                reference=-1
+            )
+
+        self.assertRaises(ValueError, test_reference_wrong_type)
+
+        def test_material_id_wrong_type():
+            """checks a ValueError is raised when the material_id is the
+            not an int"""
+
+            nmm.Material(
+                "Li4SiO4",
+                material_id='one'
+            )
+
+        self.assertRaises(ValueError, test_material_id_wrong_type)
+
         # TODO get this working
         # def no_enrichment_target():
         #     """checks a ValueError is raised when the enrichment target is set to none"""
@@ -722,6 +938,17 @@ class test_object_properties(unittest.TestCase):
         assert test_material_in_json_form["temperature_in_C"] == 100
         assert test_material_in_json_form["material_name"] == "H2O"
 
+    @staticmethod
+    def test_restricted_eval():
+        """Test that arbitrary commands cannot be injected."""
+        with pytest.raises(NameError):
+            nmm.Material(
+                "BadMaterial",
+                temperature_in_C=100,
+                pressure_in_Pa=1e6,
+                density_equation="os.system('ls')"
+            )
+
 
 if __name__ == "__main__":
 
